responsive_scale/animated_responsive_transition library

Classes

AnimatedResponsiveTransition
A widget that animates smoothly between different responsive layouts when the screen type changes (e.g., during window resize on Desktop/Web).

Enums

ResponsiveTransitionType
The type of transition animation used between responsive layouts.