autoOptimize property
Whether to automatically resize the decoded image to match the
display size, reducing memory usage. Default: false.
When true, uses ResizeImage to decode at the exact display size.
Implementation
final bool autoOptimize;
Whether to automatically resize the decoded image to match the
display size, reducing memory usage. Default: false.
When true, uses ResizeImage to decode at the exact display size.
final bool autoOptimize;