showInSidebar property
Whether to show this destination in sidebar mode.
If false, this destination is hidden in the sidebar.
Default: true.
Implementation
final bool showInSidebar;
Whether to show this destination in sidebar mode.
If false, this destination is hidden in the sidebar.
Default: true.
final bool showInSidebar;