bottomNavBuilder property
Optional builder for a fully custom bottom navigation bar. If null, a default NavigationBar (Material 3) is used.
Implementation
final BottomNavBuilder? bottomNavBuilder;
Optional builder for a fully custom bottom navigation bar. If null, a default NavigationBar (Material 3) is used.
final BottomNavBuilder? bottomNavBuilder;