railBreakpoint property
The ScreenType at which to switch from bottom nav to rail. Default: ScreenType.mobile (rail starts at tablet).
Implementation
final ScreenType railBreakpoint;
The ScreenType at which to switch from bottom nav to rail. Default: ScreenType.mobile (rail starts at tablet).
final ScreenType railBreakpoint;