sidebarBreakpoint property
The ScreenType at which to switch from rail to full sidebar. Default: ScreenType.smallDesktop (sidebar starts at desktop).
Implementation
final ScreenType sidebarBreakpoint;
The ScreenType at which to switch from rail to full sidebar. Default: ScreenType.smallDesktop (sidebar starts at desktop).
final ScreenType sidebarBreakpoint;