SpacingExtension extension

Extension on Spacing for generating scaled UI elements.

All getters use GlobalResponsive for the current scale factor, meaning they work without a BuildContext — matching the behavior of .w, .h, .fz extensions.

on

Properties

gap SizedBox

Available on Spacing, provided by the SpacingExtension extension

A vertical SizedBox with scaled height.
no setter
gapAll SizedBox

Available on Spacing, provided by the SpacingExtension extension

A SizedBox with both scaled width and height.
no setter
gapW SizedBox

Available on Spacing, provided by the SpacingExtension extension

A horizontal SizedBox with scaled width.
no setter
insets EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.all(scaled).
no setter
insetsB EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.only(bottom: scaled).
no setter
insetsH EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.symmetric(horizontal: scaled).
no setter
insetsL EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.only(left: scaled).
no setter
insetsR EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.only(right: scaled).
no setter
insetsT EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.only(top: scaled).
no setter
insetsV EdgeInsets

Available on Spacing, provided by the SpacingExtension extension

EdgeInsets.symmetric(vertical: scaled).
no setter
value double

Available on Spacing, provided by the SpacingExtension extension

The scaled value based on the general scale factor.
no setter