hiddenColumnsOnMobile property
Column indices to hide on mobile screens (0-indexed). These columns are excluded from both the default card and from the mobileCardBuilder's provided data.
Implementation
final List<int>? hiddenColumnsOnMobile;
Column indices to hide on mobile screens (0-indexed). These columns are excluded from both the default card and from the mobileCardBuilder's provided data.
final List<int>? hiddenColumnsOnMobile;