horizontalScroll property
Whether the table should have horizontal scroll on desktop
when columns overflow. Default: true.
Implementation
final bool horizontalScroll;
Whether the table should have horizontal scroll on desktop
when columns overflow. Default: true.
final bool horizontalScroll;