tableBreakpoint property
The ScreenType at which to switch from cards to table. Default: ScreenType.mobile (table starts at tablet).
Implementation
final ScreenType tableBreakpoint;
The ScreenType at which to switch from cards to table. Default: ScreenType.mobile (table starts at tablet).
final ScreenType tableBreakpoint;