autoResize property
Whether to automatically shrink the font to fit available width.
Defaults to false for maximum performance (no LayoutBuilder).
Implementation
final bool autoResize;
Whether to automatically shrink the font to fit available width.
Defaults to false for maximum performance (no LayoutBuilder).
final bool autoResize;