stepGranularity property
The step size for font size reduction during auto-resize.
Smaller values = more precise fit but slightly more computation.
Defaults to 0.5.
Implementation
final double stepGranularity;
The step size for font size reduction during auto-resize.
Smaller values = more precise fit but slightly more computation.
Defaults to 0.5.
final double stepGranularity;