crossAxisAlignment property
Alignment of children along the cross axis within each run.
Implementation
final WrapCrossAlignment crossAxisAlignment;
Alignment of children along the cross axis within each run.
final WrapCrossAlignment crossAxisAlignment;