scaleSpacing property
Whether to scale spacing and runSpacing using Scalify.
Set to false if you want fixed pixel values. Default: true.
Implementation
final bool scaleSpacing;
Whether to scale spacing and runSpacing using Scalify.
Set to false if you want fixed pixel values. Default: true.
final bool scaleSpacing;