floating property
Whether the app bar should become visible as soon as the user scrolls
towards the app bar. Default: false.
Implementation
final bool floating;
Whether the app bar should become visible as soon as the user scrolls
towards the app bar. Default: false.
final bool floating;