NavDestination class
A destination item for ResponsiveNavigation.
Constructors
-
Creates a NavDestination.
const
Properties
- badge → int?
-
Optional badge count (e.g., notifications).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
The icon for this destination.
final
- label → String
-
The label text for this destination.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIcon → IconData?
-
The selected icon for this destination.
If null, icon is used for both states.
final
- showInSidebar → bool
-
Whether to show this destination in sidebar mode.
If
false, this destination is hidden in the sidebar. Default:true.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited