ScalifySpacing class
The global spacing scale instance.
Initialized with default values. Override by calling ScalifySpacing.init with a custom SpacingScale.
ScalifySpacing.init(const SpacingScale(xs: 2, sm: 4, md: 8, lg: 16, xl: 24, xxl: 32));
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- scale → SpacingScale
-
Returns the current spacing scale.
no setter
Static Methods
-
init(
SpacingScale scale) → void - Initializes the global spacing scale.
-
reset(
) → void - Resets to default values. Intended for testing only.