ScalifySliverHeader class

A responsive sliver header that displays different widgets based on the current screen type, designed for use inside CustomScrollView.

Example

CustomScrollView(
  slivers: [
    ScalifySliverHeader(
      mobile: SliverToBoxAdapter(child: CompactHeader()),
      desktop: SliverToBoxAdapter(child: ExpandedHeader()),
    ),
    ResponsiveGrid(useSliver: true, ...),
  ],
)
Inheritance

Constructors

ScalifySliverHeader({Key? key, required Widget mobile, Widget? tablet, Widget? smallDesktop, Widget? desktop, Widget? largeDesktop})
Creates a ScalifySliverHeader.
const

Properties

desktop Widget?
Widget for desktop screens. Falls back down the chain.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
largeDesktop Widget?
Widget for large desktop screens. Falls back down the chain.
final
mobile Widget
Widget for mobile/watch screens. Required as fallback.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallDesktop Widget?
Widget for small desktop. Falls back to tabletmobile.
final
tablet Widget?
Widget for tablet screens. Falls back to mobile.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited