ScalifySliverPersistentHeader class
A responsive SliverPersistentHeader that adjusts its max/min height based on the screen type and scales content proportionally.
Example
CustomScrollView(
slivers: [
ScalifySliverPersistentHeader(
mobileMaxHeight: 80,
desktopMaxHeight: 120,
builder: (context, shrinkOffset, overlapsContent) {
return Container(
color: Colors.blue,
child: Center(child: Text('Sticky Header')),
);
},
),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ScalifySliverPersistentHeader
Constructors
- ScalifySliverPersistentHeader({Key? key, required Widget builder(BuildContext context, double shrinkOffset, bool overlapsContent), required double mobileMaxHeight, double? tabletMaxHeight, double? desktopMaxHeight, double? minHeight, bool pinned = true, bool floating = false})
-
Creates a ScalifySliverPersistentHeader.
const
Properties
- builder → Widget Function(BuildContext context, double shrinkOffset, bool overlapsContent)
-
Builder for the header content.
final
- desktopMaxHeight → double?
-
Max height on desktop. Falls back to tabletMaxHeight.
final
- floating → bool
-
Whether this header should float. Default:
false.final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minHeight → double?
-
Min height (collapsed). Default: half of the resolved max height.
final
- mobileMaxHeight → double
-
Max height on mobile. Required as fallback.
final
- pinned → bool
-
Whether this header should remain pinned. Default:
true.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabletMaxHeight → double?
-
Max height on tablet. Falls back to mobileMaxHeight.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited